#!/bin/bash
#
# Small script to create a Microsoft Exchange-like maildir structure.
# Don't hurts existing folders.
# Part of vexim-addons package.

CUT="/usr/bin/cut"				# cut command call
FIND="/usr/bin/find"				# find command call
MAILDIRMAKE="/usr/bin/maildirmake"		# maildirmake command call

# Literals
MAILDIR_DRAFTS="Drafts"                         # Exchange-like subfolder
MAILDIR_SENT="Sent"                             # Exchange-like subfolder
MAILDIR_TRASH="Trash"                           # Exchange-like subfolder

# Messages
MSG_USAGE="Small script to create a Microsoft Exchange-like maildir structure.\nUsage: $0 path-to-Maildir [ UID [ GID ]]"

# Checking components
if [ ! -x "$CUT" ]; then exit 1; fi
if [ ! -x "$FIND" ]; then exit 1; fi
if [ ! -x "$MAILDIRMAKE" ]; then exit 1; fi

# Getting pathname, optional VMAIL_UID and VMAIL_GID
MAILDIR=$1; shift
if [ -z "$MAILDIR" ]; then echo -e $MSG_USAGE; exit 1; fi
VMAIL_UID=${1:-`id -u mail`}; shift
VMAIL_GID=${1:-`id -g mail`}; shift

# Maildir itself
if [ ! -d "$MAILDIR" ]; then 
    $MAILDIRMAKE $MAILDIR 2>/dev/null
    # Only root can set access rights
    if [ $UID -eq 0 ]; then
	chown -R $VMAIL_UID:$VMAIL_GID $MAILDIR 2>/dev/null
	$FIND $MAILDIR -type d -exec chmod 700 {} \; 2>/dev/null
	$FIND $MAILDIR -type f -exec chmod 600 {} \; 2>/dev/null
    fi
fi
if [ ! -d "$MAILDIR" ]; then exit 1; fi			# On failure stops

# Subfolders
VMAIL_UID=`ls -lad $MAILDIR | $CUT -d " " -f 3`		# Maildir's UID used
VMAIL_GID=`ls -lad $MAILDIR | $CUT -d " " -f 4`		# Maildir's GID used
for subdir in "$MAILDIR_DRAFTS" "$MAILDIR_SENT" "$MAILDIR_TRASH"
do
    if [ ! -d "$MAILDIR/.$subdir" ]; then
	$MAILDIRMAKE -f $subdir $MAILDIR
        # Only root can set access rights
	if [ $UID -eq 0 ]; then
	    chown -R $VMAIL_UID:$VMAIL_GID $MAILDIR/.$subdir
	    $FIND $MAILDIR/.$subdir -type d -exec chmod 700 {} \;
	    $FIND $MAILDIR/.$subdir -type f -exec chmod 600 {} \;
	fi
    fi    
done
