#!/bin/bash
#
# Small script to revert maildir_archive.sh changes and restore Maildir.
# Part of vexim-addons package.
#
# Call with domain/mailbox relative pathname parameter OR an absolute
# pathname pointing to Maildir to revert as root.
# Pointed Maildir must contain an archive created by maildir_archive.sh!

EXIT_ERR=1                              # Exit code on failure
GREP=$(which grep)                      # grep command call
MAILROOT="/var/mail/.vexim"             # Mail storage root path
SED=$(which sed)                        # sed command call

MSG_VEXIM_BADARCHIVE="Seems not to be an archive Maildir: "
MSG_VEXIM_NOMAILDIR="Maildir isn't found at"
MSG_USAGE="Usage: $0 relative_pathname_to_mailbox OR absolute_pathname_to_Maildir"

# Mandatory parameter: relative or absolute pathname.
PATHNAME=$1; shift
if [ -z "$PATHNAME" ]; then echo -e "$MSG_USAGE"; exit $EXIT_ERR; fi
# Check pathname for relative.
MAILDIR="$MAILROOT/$PATHNAME/Maildir"
if [ ! -d "$MAILDIR" ]; then
    # On failure check for absolute pathname.
    MAILDIR=$(echo "/$PATHNAME" | $SED "s/\/\//\//g")
    if [ ! -d "$MAILDIR" -o $(basename $MAILDIR) != "Maildir" ]; then
	echo -e "$MSG_VEXIM_NOMAILDIR $MAILDIR" >&2; exit $EXIT_ERR
    fi
fi
# Maildir localised, check contents.
# ARCHNAME contains only one dot (at beginning).
ARCHNAME=$(ls -A1 "$MAILDIR" | $GREP -e '^\.[^\.]*$')
# Giving up on failure.
if [ -z "$ARCHNAME" ]; then
    echo -e "$MSG_VEXIM_BADARCHIVE $MAILDIR" >&2; exit $EXIT_ERR; fi
# Giving up when not all items beginning with ARCHNAME.
if [ "$(ls -A1 "$MAILDIR" | $GREP -v "$ARCHNAME\.")" != "$ARCHNAME" ]; then
    echo -e "$MSG_VEXIM_BADARCHIVE $MAILDIR" >&2; exit $EXIT_ERR; fi
# Test passed.

# Deleting (logically empty) ARCHNAME folder.
rm -R "$MAILDIR/$ARCHNAME"
# Renaming other folders, deleting ARCHNAME from folder name.
for content in $(ls -A1 "$MAILDIR")
do
    filename=$(echo "$content" | $SED "s/^$ARCHNAME//")
    mv "$MAILDIR/$content" "$MAILDIR/$filename"
done
# Extracting Inbox (if any).
if [ -d "$MAILDIR/.Inbox" ]; then
    mv -n $MAILDIR/.Inbox/* "$MAILDIR/"
    rmdir "$MAILDIR/.Inbox"
fi

# That's all, folks!
