#!/bin/bash
#
# Small script to update VExim configuration.
# Run once per updates as root.
# Part of vexim-addons package.

DIFF="/usr/bin/diff"
EXIM4_CONFDIR="/etc/exim4"
VEXIM_CONFFILES="main/00_exim4-config_custom_settings main/00_vexim_domains main/99_exim4-config_custom_settings"
VEXIM_CRONFILES="/etc/cron.d/mysql-vexim /etc/cron.hourly/courier-autoshare"
VEXIM_EXIMFILES="auth/30_exim4-config_courier router/190_vexim-virtual_disabled_domains router/250_vexim-virtual_domains transport/30_vexim_virtual_delivery"
VEXIM_LOCALFILES="local_acl_check_data local_acl_check_recipient local_acl_deny_exceptions local_host_blacklist local_host_whitelist local_sender_blacklist local_sender_whitelist"
VEXIM_TEMPLATES="/usr/local/share/vexim-addons/template"

MSG_VEXIM_CREATED="created from template."
MSG_VEXIM_EXISTS="exists, leaving alone."
MSG_VEXIM_MISSING="missing!"
MSG_VEXIM_NODIFF="$DIFF missing, doesn't show differences!"

# Checking diff, alerts when missing.
if [ ! -x "$DIFF" ]; then echo "$MSG_VEXIM_NODIFF"; fi

# Exim4 cronjobs.
for filename in $VEXIM_CRONFILES
do
    if [ -f "$filename" ]; then
	echo "$filename $MSG_VEXIM_EXISTS"
	if [ -x "$DIFF" -a -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    $DIFF "$filename" "$VEXIM_TEMPLATES/$(basename $filename)"
	fi
    else
	if [ -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    cp -p -v "$VEXIM_TEMPLATES/$(basename $filename)" "$filename"
	else
	    echo "$VEXIM_TEMPLATES/$(basename $filename) $MSG_VEXIM_MISSING"
	fi
    fi
done

# Exim4 static addons (routers, transports, etc.).
for filename in $VEXIM_EXIMFILES
do
    if [ -f "$EXIM4_CONFDIR/conf.d/$filename" ]; then
	echo "$EXIM4_CONFDIR/conf.d/$filename $MSG_VEXIM_EXISTS"
	if [ -x "$DIFF" -a -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    $DIFF "$EXIM4_CONFDIR/conf.d/$filename" "$VEXIM_TEMPLATES/$(basename $filename)"
	fi
    else
	if [ -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    cp -p -v "$VEXIM_TEMPLATES/$(basename $filename)" "$EXIM4_CONFDIR/conf.d/$filename"
	else
	    echo "$VEXIM_TEMPLATES/$(basename filename) $MSG_VEXIM_MISSING"
	fi
    fi
done

# Exim4 configuration addons.
for filename in $VEXIM_CONFFILES
do
    if [ -f "$EXIM4_CONFDIR/conf.d/$filename" ]; then
	echo "$EXIM4_CONFDIR/conf.d/$filename $MSG_VEXIM_EXISTS"
	if [ -x "$DIFF" -a -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    $DIFF "$EXIM4_CONFDIR/conf.d/$filename" "$VEXIM_TEMPLATES/$(basename $filename)"
	fi
    else
	if [ -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    cp -p -v "$VEXIM_TEMPLATES/$(basename $filename)" "$EXIM4_CONFDIR/conf.d/$filename"
	else
	    echo "$VEXIM_TEMPLATES/$(basename filename) $MSG_VEXIM_MISSING"
	fi
    fi
done

# Exim4 local config textfiles.
for filename in $VEXIM_LOCALFILES
do
    if [ -f "$EXIM4_CONFDIR/$filename" ]; then
	echo "$EXIM4_CONFDIR/$filename $MSG_VEXIM_EXISTS"
	if [ -x "$DIFF" -a -f "$VEXIM_TEMPLATES/$(basename $filename)" ]; then
	    $DIFF "$EXIM4_CONFDIR/$filename" "$VEXIM_TEMPLATES/$(basename $filename)"
	fi
    else
	if [ -f "$VEXIM_TEMPLATES/$filename" ]; then
	    cp -p -v "$VEXIM_TEMPLATES/$filename" "$EXIM4_CONFDIR/$filename"
	else
	    echo "$VEXIM_TEMPLATES/$filename $MSG_VEXIM_MISSING"
	fi
    fi
done

# That's all, folks! :-)
